@@ -909,7 +909,6 @@ clutter_animation_update (ClutterAnimation *animation,
                           const gchar      *property_name,
                           const GValue     *final)
 {
-  ClutterAnimationPrivate *priv;
   ClutterInterval *interval;
   GType int_type;
 
@@ -918,8 +917,6 @@ clutter_animation_update (ClutterAnimation *animation,
   g_return_val_if_fail (final != NULL, NULL);
   g_return_val_if_fail (G_VALUE_TYPE (final) != G_TYPE_INVALID, NULL);
 
-  priv = animation->priv;
-
   interval = clutter_animation_get_interval (animation, property_name);
   if (interval == NULL)
     {
@@ -1536,7 +1533,12 @@ clutter_animation_set_alpha (ClutterAnimation *animation,
                           animation);
     }
   else
-    timeline = clutter_animation_get_timeline_internal (animation);
+    {
+      /* FIXME - add a create_timeline_internal() because this does
+       * not look very good
+       */
+      (void) clutter_animation_get_timeline_internal (animation);
+    }
 
 out:
   /* emit all relevant notifications */
@@ -1835,8 +1837,16 @@ clutter_animation_setup_valist (ClutterAnimation *animation,
               break;
             }
 
+#if GLIB_CHECK_VERSION (2, 23, 2)
+          G_VALUE_COLLECT_INIT (&final, G_PARAM_SPEC_VALUE_TYPE (pspec),
+                                var_args, 0,
+                                &error);
+#else
+          /* this is the same as G_VALUE_COLLECT_INIT(), but slower */
           g_value_init (&final, G_PARAM_SPEC_VALUE_TYPE (pspec));
           G_VALUE_COLLECT (&final, var_args, 0, &error);
+#endif /* GLIB_CHECK_VERSION (2, 23, 2) */
+
           if (error)
             {
               g_warning ("%s: %s", G_STRLOC, error);
@@ -2040,11 +2050,10 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  * to control the animation or to know when the animation has been
  * completed.
  *
- * If a name argument starts with "signal::", "signal-after::" or
- * "signal-swapped::" the two following arguments are used as callback
- * function and data for a signal handler installed on the
- * #ClutterAnimation object for the specified signal name, for
- * instance:
+ * If a name argument starts with "signal::", "signal-after::",
+ * "signal-swapped::" or "signal-swapped-after::" the two following arguments
+ * are used as callback function and data for a signal handler installed on
+ * the #ClutterAnimation object for the specified signal name, for instance:
  *
  * |[
  *
@@ -2061,13 +2070,28 @@ clutter_actor_animate_with_timeline (ClutterActor    *actor,
  *                          NULL);
  * ]|
  *
+ * or, to automatically destroy an actor at the end of the animation:
+ *
+ * |[
+ *   clutter_actor_animate (actor, CLUTTER_EASE_IN_CUBIC, 100,
+ *                          "opacity", 0,
+ *                          "signal-swapped-after::completed",
+ *                            clutter_actor_destroy,
+ *                            actor,
+ *                          NULL);
+ * ]|
+ *
  * The "signal::" modifier is the equivalent of using g_signal_connect();
  * the "signal-after::" modifier is the equivalent of using
- * g_signal_connect_after(); the "signal-swapped::" modifier is the equivalent
- * of using g_signal_connect_swapped(). The clutter_actor_animate() function
- * will not keep track of multiple connections to the same signal, so it is
- * your responsability to avoid them when calling clutter_actor_animate()
- * multiple times on the same actor.
+ * g_signal_connect_after() or g_signal_connect_data() with the
+ * %G_CONNECT_AFTER; the "signal-swapped::" modifier is the equivalent
+ * of using g_signal_connect_swapped() or g_signal_connect_data() with the
+ * %G_CONNECT_SWAPPED flah; finally, the "signal-swapped-after::" modifier
+ * is the equivalent of using g_signal_connect_data() with both the
+ * %G_CONNECT_AFTER and %G_CONNECT_SWAPPED flags. The clutter_actor_animate()
+ * function will not keep track of multiple connections to the same signal,
+ * so it is your responsability to avoid them when calling
+ * clutter_actor_animate() multiple times on the same actor.
  *
  * Calling this function on an actor that is already being animated
  * will cause the current animation to change with the new final values,
@@ -2171,7 +2195,7 @@ clutter_actor_animate (ClutterActor *actor,
  * @n_properties: number of property names and values
  * @properties: (array length=n_properties) (element-type utf8): a vector
  *    containing the property names to set
- * @values: (array length=n_properies): a vector containing the
+ * @values: (array length=n_properties): a vector containing the
  *    property values to set
  *
  * Animates the given list of properties of @actor between the current
@@ -2223,7 +2247,7 @@ clutter_actor_animatev (ClutterActor        *actor,
  * @n_properties: number of property names and values
  * @properties: (array length=n_properties) (element-type utf8): a vector
  *    containing the property names to set
- * @values: (array length=n_properies): a vector containing the
+ * @values: (array length=n_properties): a vector containing the
  *    property values to set
  *
  * Animates the given list of properties of @actor between the current
@@ -2278,7 +2302,7 @@ clutter_actor_animate_with_timelinev (ClutterActor        *actor,
  * @n_properties: number of property names and values
  * @properties: (array length=n_properties) (element-type utf8): a vector
  *    containing the property names to set
- * @values: (array length=n_properies): a vector containing the
+ * @values: (array length=n_properties): a vector containing the
  *    property values to set
  *
  * Animates the given list of properties of @actor between the current
