@@ -823,11 +823,11 @@ cogl_material_set_layer (CoglHandle material_handle,
   _cogl_material_pre_change_notify (material, FALSE, NULL);
 
   material->n_layers = g_list_length (material->layers);
-  if (material->n_layers >= _cogl_get_max_texture_image_units ())
+  if (material->n_layers > _cogl_get_max_texture_image_units ())
     {
       if (!(material->flags & COGL_MATERIAL_FLAG_SHOWN_SAMPLER_WARNING))
 	{
-	  g_warning ("Your hardware does not have enough texture samplers"
+	  g_warning ("Your hardware does not have enough texture samplers "
 		     "to handle this many texture layers");
 	  material->flags |= COGL_MATERIAL_FLAG_SHOWN_SAMPLER_WARNING;
 	}
@@ -1390,8 +1390,10 @@ _cogl_material_flush_layers_gl_state (CoglMaterial *material,
 
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
-  for (tmp = material->layers, i = 0; tmp != NULL; tmp = tmp->next, i++)
-    {
+  for (tmp = material->layers, i = 0;
+       tmp != NULL && i < _cogl_get_max_texture_image_units ();
+       tmp = tmp->next, i++)
+   {
       CoglHandle         layer_handle = (CoglHandle)tmp->data;
       CoglMaterialLayer *layer =
         _cogl_material_layer_pointer_from_handle (layer_handle);
@@ -1538,9 +1540,6 @@ _cogl_material_flush_layers_gl_state (CoglMaterial *material,
         g_array_append_val (ctx->current_layers, new_gl_layer_info);
 
       layer->flags &= ~COGL_MATERIAL_LAYER_FLAG_DIRTY;
-
-      if ((i+1) >= _cogl_get_max_texture_image_units ())
-	break;
     }
 
   /* Disable additional texture units that may have previously been in use.. */
