@@ -14,9 +14,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 #ifndef __CLUTTER_BACKEND_X11_H__
@@ -82,8 +82,7 @@ struct _ClutterBackendX11
 
   Time last_event_time;
 
-  ClutterInputDevice *core_pointer;
-  ClutterInputDevice *core_keyboard;
+  ClutterDeviceManager *device_manager;
 };
 
 struct _ClutterBackendX11Class
@@ -96,6 +95,13 @@ struct _ClutterBackendX11Class
    * may need to be handled differently for different backends.
    */
   XVisualInfo *(* get_visual_info) (ClutterBackendX11 *backend);
+
+  /*
+   * Different X11 backends may care about some special events so they all have
+   * a chance to intercept them.
+   */
+  gboolean (*handle_event) (ClutterBackendX11 *backend,
+                            XEvent            *xevent);
 };
 
 void   _clutter_backend_x11_events_init (ClutterBackend *backend);
